@@ -64,9 +64,11 @@
                 Pval <- rep(1, ncol(comm))
                 for (k in seq_len(nperm)) {
                     take <- tmat[permat[k,],permat[k,]][tri]
-                    Pval <- Pval + ((colMeans(spcontr[take,]) - EPS) >= average)
+                    Pval <- Pval + ((colMeans(spcontr[take,,drop = FALSE]) - EPS) >= average)
                 }
                 Pval <- Pval/(nperm+1)
+                if (anyNA(ratio))
+                    Pval[is.na(ratio)] <- NA
             } else {
                 Pval <- NULL
             }
